@@ -9,9 +9,12 @@
  *
  * Copyright 1999, 2001 Ximian, Inc.
  */
+
+#undef GTK_DISABLE_DEPRECATED
+
 #include <config.h>
 
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n-lib.h>
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-ui-private.h>
 #include <bonobo/bonobo-ui-main.h>
@@ -20,7 +23,7 @@
 
 #include <libgnome/gnome-init.h>
 
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 
 #ifdef G_OS_WIN32
 #include <string.h>
