@@ -7,16 +7,13 @@
  * Copyright (C) 2000 Ximian, Inc.
  */
 
+#undef GTK_DISABLE_DEPRECATED
+
 #include <config.h>
 #include <bonobo/bonobo-ui-private.h>
 #include <bonobo-ui-toolbar-item.h>
-#include <libgnome/gnome-macros.h>
-
-GNOME_CLASS_BOILERPLATE (BonoboUIToolbarItem,
-			 bonobo_ui_toolbar_item,
-			 GObject,
-			 GTK_TYPE_BIN);
 
+G_DEFINE_TYPE (BonoboUIToolbarItem, bonobo_ui_toolbar_item, GTK_TYPE_BIN)
 
 struct _BonoboUIToolbarItemPrivate {
 	/* Whether this item wants to have a label when the toolbar style is
@@ -60,7 +57,7 @@ impl_finalize (GObject *object)
 
 	g_free (toolbar_item->priv);
 
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+	G_OBJECT_CLASS (bonobo_ui_toolbar_item_parent_class)->finalize (object);
 }
 
 /* GtkWidget methods.  */
@@ -179,7 +176,6 @@ bonobo_ui_toolbar_item_class_init (BonoboUIToolbarItemClass *object_class)
 	gobject_class->finalize = impl_finalize;
 
 	widget_class = GTK_WIDGET_CLASS (object_class);
-	widget_class->focus = bonobo_widget_clobber_focus;
 	widget_class->size_request  = impl_size_request;
 	widget_class->size_allocate = impl_size_allocate;
 
@@ -243,7 +239,7 @@ bonobo_ui_toolbar_item_class_init (BonoboUIToolbarItemClass *object_class)
 }
 
 static void
-bonobo_ui_toolbar_item_instance_init (BonoboUIToolbarItem *toolbar_item)
+bonobo_ui_toolbar_item_init (BonoboUIToolbarItem *toolbar_item)
 {
 	BonoboUIToolbarItemPrivate *priv;
 
