@@ -6,6 +6,9 @@
  *
  * Copyright 2000, 2001 Ximian, Inc.
  */
+
+#undef GTK_DISABLE_DEPRECATED
+
 #include <config.h>
 #include <string.h>
 #include <stdlib.h>
@@ -124,6 +127,7 @@ cb_do_hide_toolbar (GtkWindow *window, BonoboWindow *win)
 		bonobo_ui_component_set_prop (global_component, path, "hidden", "0", NULL);
 	else
 		bonobo_ui_component_set_prop (global_component, path, "hidden", "1", NULL);
+	g_free (val);
 }
 
 static void
